import{S as c,i as f,s as m,e as h,a as r,b as y,n as o,h as g,z as d,o as w,q as b,u as k,v as M,w as q,D as C}from"./index.c156a17d.js";function D(a){let e;return{c(){e=h("div"),r(e,"class","output-markdown prose max-w-full"),r(e,"style",a[1])},m(n,t){y(n,e,t),e.innerHTML=a[0]},p(n,[t]){t&1&&(e.innerHTML=n[0]),t&2&&r(e,"style",n[1])},i:o,o,d(n){n&&g(e)}}}function H(a,e,n){let{value:t}=e,{style:l=""}=e;const s=d();return a.$$set=i=>{"value"in i&&n(0,t=i.value),"style"in i&&n(1,l=i.style)},a.$$.update=()=>{a.$$.dirty&1&&s("change")},[t,l]}class L extends c{constructor(e){super(),f(this,e,H,D,m,{value:0,style:1})}}function S(a){let e,n;return e=new L({props:{value:a[0],style:a[1]}}),e.$on("change",a[4]),{c(){w(e.$$.fragment)},m(t,l){b(e,t,l),n=!0},p(t,[l]){const s={};l&1&&(s.value=t[0]),l&2&&(s.style=t[1]),e.$set(s)},i(t){n||(k(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){q(e,t)}}}function T(a,e,n){let{label:t}=e,{value:l=""}=e,{default_value:s}=e,{style:i=""}=e;const v=d();s&&(l=s);function _(u){C.call(this,a,u)}return a.$$set=u=>{"label"in u&&n(2,t=u.label),"value"in u&&n(0,l=u.value),"default_value"in u&&n(3,s=u.default_value),"style"in u&&n(1,i=u.style)},a.$$.update=()=>{a.$$.dirty&4&&v("change")},[l,i,t,s,_]}class z extends c{constructor(e){super(),f(this,e,T,S,m,{label:2,value:0,default_value:3,style:1})}}var j=z;const A=["static"];export{j as Component,A as modes};
