import{S as g,i as d,s as m,P as v,e as c,a as o,t as f,b as h,M as b,N as C,O as y,u as S,v as q,h as M}from"./index.c156a17d.js";function N(s){let e,n;const i=s[5].default,a=v(i,s,s[4],null);return{c(){e=c("div"),a&&a.c(),o(e,"style",s[1]),o(e,"class","flex flex-1 flex-col gr-gap gr-form-gap relative"),f(e,"hidden",!s[0]),f(e,"bg-gray-50",s[2]==="panel"),f(e,"p-2",s[2]==="panel"),f(e,"rounded-lg",s[2]==="panel")},m(l,t){h(l,e,t),a&&a.m(e,null),n=!0},p(l,[t]){a&&a.p&&(!n||t&16)&&b(a,i,l,l[4],n?y(i,l[4],t,null):C(l[4]),null),(!n||t&2)&&o(e,"style",l[1]),t&1&&f(e,"hidden",!l[0]),t&4&&f(e,"bg-gray-50",l[2]==="panel"),t&4&&f(e,"p-2",l[2]==="panel"),t&4&&f(e,"rounded-lg",l[2]==="panel")},i(l){n||(S(a,l),n=!0)},o(l){q(a,l),n=!1},d(l){l&&M(e),a&&a.d(l)}}}function O(s,e,n){let{$$slots:i={},$$scope:a}=e,{value:l=!0}=e,{default_value:t}=e,{style:_=""}=e,{variant:r="default"}=e;return t&&(l=t),s.$$set=u=>{"value"in u&&n(0,l=u.value),"default_value"in u&&n(3,t=u.default_value),"style"in u&&n(1,_=u.style),"variant"in u&&n(2,r=u.variant),"$$scope"in u&&n(4,a=u.$$scope)},[l,_,r,t,a,i]}class P extends g{constructor(e){super(),d(this,e,O,N,m,{value:0,default_value:3,style:1,variant:2})}}var k=P;const w=["static"];export{k as Component,w as modes};
