const r=["red","green","blue","yellow","purple","teal","orange","cyan","lime","pink"],a={red:{primary:"#dc2626",secondary:"#fca5a5"},green:{primary:"#16a34a",secondary:"#86efac"},blue:{primary:"#2563eb",secondary:"#93c5fd"},yellow:{primary:"#eab308",secondary:"#fef08a"},purple:{primary:"#9333ea",secondary:"#d8b4fe"},teal:{primary:"#0d9488",secondary:"#5eead4"},orange:{primary:"#ea580c",secondary:"#fdba74"},cyan:{primary:"#0891b2",secondary:"#7dd3fc"},lime:{primary:"#84cc16",secondary:"#d9f99d"},pink:{primary:"#db2777",secondary:"#f9a8d4"}};export{a as c,r as o};
