import{S as c,i as _,s as m,P as h,e as k,a as r,b,l as z,M as B,N as q,O as w,u as g,v,h as d,D as y,o as C,q as S,w as D,I,X as M,d as N,g as O}from"./index.c156a17d.js";function P(l){let t,a,e,s,o;const f=l[4].default,i=h(f,l,l[3],null);return{c(){t=k("button"),i&&i.c(),r(t,"style",l[1]),r(t,"class",a="gr-button gr-button-"+l[2]+" gr-button-"+l[0])},m(u,n){b(u,t,n),i&&i.m(t,null),e=!0,s||(o=z(t,"click",l[5]),s=!0)},p(u,[n]){i&&i.p&&(!e||n&8)&&B(i,f,u,u[3],e?w(f,u[3],n,null):q(u[3]),null),(!e||n&2)&&r(t,"style",u[1]),(!e||n&5&&a!==(a="gr-button gr-button-"+u[2]+" gr-button-"+u[0]))&&r(t,"class",a)},i(u){e||(g(i,u),e=!0)},o(u){v(i,u),e=!1},d(u){u&&d(t),i&&i.d(u),s=!1,o()}}}function X(l,t,a){let{$$slots:e={},$$scope:s}=t,{variant:o="secondary"}=t,{style:f=""}=t,{size:i="lg"}=t;function u(n){y.call(this,l,n)}return l.$$set=n=>{"variant"in n&&a(0,o=n.variant),"style"in n&&a(1,f=n.style),"size"in n&&a(2,i=n.size),"$$scope"in n&&a(3,s=n.$$scope)},[o,f,i,s,e,u]}class j extends c{constructor(t){super(),_(this,t,X,P,m,{variant:0,style:1,size:2})}}function A(l){let t=l[3](l[0])+"",a;return{c(){a=N(t)},m(e,s){b(e,a,s)},p(e,s){s&9&&t!==(t=e[3](e[0])+"")&&O(a,t)},d(e){e&&d(a)}}}function E(l){let t,a;return t=new j({props:{variant:l[2],style:l[1],$$slots:{default:[A]},$$scope:{ctx:l}}}),t.$on("click",l[5]),{c(){C(t.$$.fragment)},m(e,s){S(t,e,s),a=!0},p(e,[s]){const o={};s&4&&(o.variant=e[2]),s&2&&(o.style=e[1]),s&73&&(o.$$scope={dirty:s,ctx:e}),t.$set(o)},i(e){a||(g(t.$$.fragment,e),a=!0)},o(e){v(t.$$.fragment,e),a=!1},d(e){D(t,e)}}}function F(l,t,a){let e;I(l,M,n=>a(3,e=n));let{value:s}=t,{default_value:o=void 0}=t,{style:f=""}=t,{variant:i="primary"}=t;o&&(s=o);function u(n){y.call(this,l,n)}return l.$$set=n=>{"value"in n&&a(0,s=n.value),"default_value"in n&&a(4,o=n.default_value),"style"in n&&a(1,f=n.style),"variant"in n&&a(2,i=n.variant)},[s,f,i,e,o,u]}class G extends c{constructor(t){super(),_(this,t,F,E,m,{value:0,default_value:4,style:1,variant:2})}}var J=G;const K=["static"];export{J as Component,K as modes};
