import{S as c,i as u,s as _,e as f,a as l,F as n,b as o,n as m,h as g}from"./index.c156a17d.js";function d(i){let e,s;return{c(){e=f("img"),l(e,"class","gr-sample-image"),n(e.src,s=i[1]+i[0])||l(e,"src",s)},m(a,t){o(a,e,t)},p(a,[t]){t&3&&!n(e.src,s=a[1]+a[0])&&l(e,"src",s)},i:m,o:m,d(a){a&&g(e)}}}function v(i,e,s){let{value:a}=e,{samples_dir:t}=e;return i.$$set=r=>{"value"in r&&s(0,a=r.value),"samples_dir"in r&&s(1,t=r.samples_dir)},[a,t]}class p extends c{constructor(e){super(),u(this,e,v,d,_,{value:0,samples_dir:1})}}var q=p;export{q as E};
