import{S as r,i as u,s as _,P as f,e as c,a as m,t as i,b,M as h,N as g,O as p,u as d,v as w,h as k}from"./index.c156a17d.js";function y(n){let t,a;const o=n[2].default,s=f(o,n,n[1],null);return{c(){t=c("span"),s&&s.c(),m(t,"class","text-gray-600 text-[0.855rem] mb-2 block"),i(t,"sr-only",!n[0])},m(e,l){b(e,t,l),s&&s.m(t,null),a=!0},p(e,[l]){s&&s.p&&(!a||l&2)&&h(s,o,e,e[1],a?p(o,e[1],l,null):g(e[1]),null),l&1&&i(t,"sr-only",!e[0])},i(e){a||(d(s,e),a=!0)},o(e){w(s,e),a=!1},d(e){e&&k(t),s&&s.d(e)}}}function B(n,t,a){let{$$slots:o={},$$scope:s}=t,{show_label:e=!0}=t;return n.$$set=l=>{"show_label"in l&&a(0,e=l.show_label),"$$scope"in l&&a(1,s=l.$$scope)},[e,s,o]}class q extends r{constructor(t){super(),u(this,t,B,y,_,{show_label:0})}}export{q as B};
