import{S as c,i as d,s as r,P as m,e as v,a as i,t as _,b as g,M as h,N as y,O as w,u as b,v as C,h as R}from"./index.c156a17d.js";function S(n){let t,s;const f=n[4].default,l=m(f,n,n[3],null);return{c(){t=v("div"),l&&l.c(),i(t,"style",n[1]),i(t,"class","flex flex-col md:flex-row gap-3"),_(t,"hidden",!n[0])},m(e,a){g(e,t,a),l&&l.m(t,null),s=!0},p(e,[a]){l&&l.p&&(!s||a&8)&&h(l,f,e,e[3],s?w(f,e[3],a,null):y(e[3]),null),(!s||a&2)&&i(t,"style",e[1]),a&1&&_(t,"hidden",!e[0])},i(e){s||(b(l,e),s=!0)},o(e){C(l,e),s=!1},d(e){e&&R(t),l&&l.d(e)}}}function q(n,t,s){let{$$slots:f={},$$scope:l}=t,{value:e}=t,{default_value:a}=t,{style:o=""}=t;return a&&(e=a),n.$$set=u=>{"value"in u&&s(0,e=u.value),"default_value"in u&&s(2,a=u.default_value),"style"in u&&s(1,o=u.style),"$$scope"in u&&s(3,l=u.$$scope)},[e,o,a,l,f]}class M extends c{constructor(t){super(),d(this,t,q,S,r,{value:0,default_value:2,style:1})}}var O=M;const P=["static"];export{O as Component,P as modes};
