import{S as g,i as p,s as y,e as D,a as m,b as h,M as k,N as T,O as C,u,v as f,h as S,j as I,x as M,y as N,z as j,a0 as z,I as A,W as B,Y as E,P as q,o as O,q as P,w as W,D as Y}from"./index.c156a17d.js";import{a as F}from"./Tabs.74243509.js";function d(a){let s,l;const e=a[6].default,t=q(e,a,a[5],null);return{c(){s=D("div"),t&&t.c(),m(s,"class","p-2 border-2 border-t-0 border-gray-200 relative"),m(s,"style",a[0])},m(n,o){h(n,s,o),t&&t.m(s,null),l=!0},p(n,o){t&&t.p&&(!l||o&32)&&k(t,e,n,n[5],l?C(e,n[5],o,null):T(n[5]),null),(!l||o&1)&&m(s,"style",n[0])},i(n){l||(u(t,n),l=!0)},o(n){f(t,n),l=!1},d(n){n&&S(s),t&&t.d(n)}}}function G(a){let s,l,e=a[1]===a[2]&&d(a);return{c(){e&&e.c(),s=I()},m(t,n){e&&e.m(t,n),h(t,s,n),l=!0},p(t,[n]){t[1]===t[2]?e?(e.p(t,n),n&2&&u(e,1)):(e=d(t),e.c(),u(e,1),e.m(s.parentNode,s)):e&&(M(),f(e,1,1,()=>{e=null}),N())},i(t){l||(u(e),l=!0)},o(t){f(e),l=!1},d(t){e&&e.d(t),t&&S(s)}}}function H(a,s,l){let e,{$$slots:t={},$$scope:n}=s,{name:o}=s,{style:c=""}=s;const r=j(),_={},{register_tab:v,unregister_tab:w,selected_tab:b}=z(F);return A(a,b,i=>l(1,e=i)),v({name:o,id:_}),B(()=>()=>w({name:o,id:_})),a.$$set=i=>{"name"in i&&l(4,o=i.name),"style"in i&&l(0,c=i.style),"$$scope"in i&&l(5,n=i.$$scope)},a.$$.update=()=>{a.$$.dirty&2&&e===_&&E().then(()=>r("select"))},[c,e,_,b,o,n,t]}class J extends g{constructor(s){super(),p(this,s,H,G,y,{name:4,style:0})}}function K(a){let s;const l=a[2].default,e=q(l,a,a[4],null);return{c(){e&&e.c()},m(t,n){e&&e.m(t,n),s=!0},p(t,n){e&&e.p&&(!s||n&16)&&k(e,l,t,t[4],s?C(l,t[4],n,null):T(t[4]),null)},i(t){s||(u(e,t),s=!0)},o(t){f(e,t),s=!1},d(t){e&&e.d(t)}}}function L(a){let s,l;return s=new J({props:{style:a[1],name:a[0],$$slots:{default:[K]},$$scope:{ctx:a}}}),s.$on("select",a[3]),{c(){O(s.$$.fragment)},m(e,t){P(s,e,t),l=!0},p(e,[t]){const n={};t&2&&(n.style=e[1]),t&1&&(n.name=e[0]),t&16&&(n.$$scope={dirty:t,ctx:e}),s.$set(n)},i(e){l||(u(s.$$.fragment,e),l=!0)},o(e){f(s.$$.fragment,e),l=!1},d(e){W(s,e)}}}function Q(a,s,l){let{$$slots:e={},$$scope:t}=s,{label:n}=s,{style:o=""}=s;function c(r){Y.call(this,a,r)}return a.$$set=r=>{"label"in r&&l(0,n=r.label),"style"in r&&l(1,o=r.style),"$$scope"in r&&l(4,t=r.$$scope)},[n,o,e,c,t]}class R extends g{constructor(s){super(),p(this,s,Q,L,y,{label:0,style:1})}}var X=R;const Z=["static"];export{X as Component,Z as modes};
