import{S as B,i as S,s as b,e as j,a as d,t as r,b as v,M as k,N as q,O as C,u as h,v as c,h as y,j as M,P as O}from"./index.c156a17d.js";function _(i){let e,o,s;const t=i[9].default,l=O(t,i,i[8],null);return{c(){e=j(i[6]),l&&l.c(),d(e,"data-testid",i[4]),d(e,"class",o="gr-box overflow-hidden "+i[5][i[0]]+" "+i[5][i[1]]),r(e,"gr-panel",i[2]),r(e,"form",i[3]),r(e,"!rounded-none",i[3]==="mid"),r(e,"!rounded-b-none",i[3]==="first"),r(e,"!rounded-t-none",i[3]==="last")},m(n,a){v(n,e,a),l&&l.m(e,null),s=!0},p(n,a){l&&l.p&&(!s||a&256)&&k(l,t,n,n[8],s?C(t,n[8],a,null):q(n[8]),null),(!s||a&16)&&d(e,"data-testid",n[4]),(!s||a&3&&o!==(o="gr-box overflow-hidden "+n[5][n[0]]+" "+n[5][n[1]]))&&d(e,"class",o),a&7&&r(e,"gr-panel",n[2]),a&11&&r(e,"form",n[3]),a&11&&r(e,"!rounded-none",n[3]==="mid"),a&11&&r(e,"!rounded-b-none",n[3]==="first"),a&11&&r(e,"!rounded-t-none",n[3]==="last")},i(n){s||(h(l,n),s=!0)},o(n){c(l,n),s=!1},d(n){n&&y(e),l&&l.d(n)}}}function P(i){let e=i[6],o,s,t=i[6]&&_(i);return{c(){t&&t.c(),o=M()},m(l,n){t&&t.m(l,n),v(l,o,n),s=!0},p(l,[n]){l[6]?e?b(e,l[6])?(t.d(1),t=_(l),t.c(),t.m(o.parentNode,o)):t.p(l,n):(t=_(l),t.c(),t.m(o.parentNode,o)):e&&(t.d(1),t=null),e=l[6]},i(l){s||(h(t),s=!0)},o(l){c(t),s=!1},d(l){l&&y(o),t&&t.d(l)}}}function z(i,e,o){let{$$slots:s={},$$scope:t}=e,{variant:l="solid"}=e,{color:n="grey"}=e,{padding:a=!0}=e,{form_position:m=void 0}=e,{type:u="normal"}=e,{test_id:g=void 0}=e;const N={dashed:"border-dashed border-[3px]",solid:"border-solid border",grey:"border-gray-200",green:"border-green-400"};let w=u==="fieldset"?"fieldset":"div";return i.$$set=f=>{"variant"in f&&o(0,l=f.variant),"color"in f&&o(1,n=f.color),"padding"in f&&o(2,a=f.padding),"form_position"in f&&o(3,m=f.form_position),"type"in f&&o(7,u=f.type),"test_id"in f&&o(4,g=f.test_id),"$$scope"in f&&o(8,t=f.$$scope)},[l,n,a,m,g,N,w,u,t,s]}class D extends B{constructor(e){super(),S(this,e,z,P,b,{variant:0,color:1,padding:2,form_position:3,type:7,test_id:4})}}export{D as B};
