import{S as d,i as $,s as h,o as c,q as m,u as f,v as i,w as g,J as b,P as k,k as C,b as y,K as S,L as w,M as q,N as v,O as j,h as D,D as J}from"./index.c156a17d.js";import{C as K}from"./CarouselItem.svelte_svelte_type_style_lang.4b9ee72d.js";import{S as L}from"./StatusTracker.f0d63e01.js";function M(n){let e,o,s;const r=[n[1]];let l={};for(let t=0;t<r.length;t+=1)l=b(l,r[t]);e=new L({props:l});const _=n[2].default,a=k(_,n,n[4],null);return{c(){c(e.$$.fragment),o=C(),a&&a.c()},m(t,u){m(e,t,u),y(t,o,u),a&&a.m(t,u),s=!0},p(t,u){const p=u&2?S(r,[w(t[1])]):{};e.$set(p),a&&a.p&&(!s||u&16)&&q(a,_,t,t[4],s?j(_,t[4],u,null):v(t[4]),null)},i(t){s||(f(e.$$.fragment,t),f(a,t),s=!0)},o(t){i(e.$$.fragment,t),i(a,t),s=!1},d(t){g(e,t),t&&D(o),a&&a.d(t)}}}function N(n){let e,o;return e=new K({props:{style:n[0],$$slots:{default:[M]},$$scope:{ctx:n}}}),e.$on("change",n[3]),{c(){c(e.$$.fragment)},m(s,r){m(e,s,r),o=!0},p(s,[r]){const l={};r&1&&(l.style=s[0]),r&18&&(l.$$scope={dirty:r,ctx:s}),e.$set(l)},i(s){o||(f(e.$$.fragment,s),o=!0)},o(s){i(e.$$.fragment,s),o=!1},d(s){g(e,s)}}}function O(n,e,o){let{$$slots:s={},$$scope:r}=e,{style:l=""}=e,{loading_status:_}=e;function a(t){J.call(this,n,t)}return n.$$set=t=>{"style"in t&&o(0,l=t.style),"loading_status"in t&&o(1,_=t.loading_status),"$$scope"in t&&o(4,r=t.$$scope)},[l,_,s,a,r]}class P extends d{constructor(e){super(),$(this,e,O,N,h,{style:0,loading_status:1})}}var B=P;const E=["static"];export{B as Component,E as modes};
